import { BaseRoute, FetchOptions, Options } from "./base";
import type { DailyRewardSignInHistoryData, DayReward, DailyRewardSignInData, DailyRewardInfoData, DailyRewardExtraRewardData, DailyRewardResignData, MonthRewardData } from "../interface";
import type { ClientCookieManager } from "../client/clientCookieManager";
export type FetchClaimHistoryOption = FetchOptions & {
    page?: number;
};
export type CheckInFetchOptions = FetchOptions & {
    geetestCallback?: (challenge: string, gt: string) => Promise<{
        validate: string;
        seccode: string;
    }>;
};
declare class RewardInfo extends BaseRoute<DailyRewardInfoData> {
    private readonly defaultOptions?;
    constructor(options?: Options);
    /**
     * @description Get the daily rewards info
     */
    fetch(options?: FetchOptions): Promise<DailyRewardInfoData>;
    /**
     * @description Get the daily rewards details for a specific day
     * @param {number} day The day to fetch
     */
    fetchDay(day: number, options?: FetchOptions): Promise<DayReward>;
    /**
     * @description Get the daily rewards details
     */
    fetchMonth(options?: FetchOptions): Promise<MonthRewardData>;
}
declare class ExtraRewardInfo extends BaseRoute<DailyRewardExtraRewardData> {
    private readonly defaultOptions?;
    constructor(options?: Options);
    /**
     * @description Get the extra rewards info
     */
    fetch(options?: FetchOptions): Promise<DailyRewardExtraRewardData>;
}
declare class ResignInfo extends BaseRoute<DailyRewardResignData> {
    private readonly defaultOptions?;
    constructor(options?: Options);
    /**
     * @description get resign info
     */
    fetch(options?: FetchOptions): Promise<DailyRewardResignData>;
}
declare class CheckInHistory extends BaseRoute<DailyRewardSignInHistoryData> {
    private readonly defaultOptions?;
    constructor(options?: Options);
    /**
     * @description get check in history
     */
    fetch(options?: FetchClaimHistoryOption): Promise<DailyRewardSignInHistoryData>;
}
export declare class DailyRewards {
    private readonly defaultOptions?;
    readonly cookieManager?: ClientCookieManager;
    rewardInfo: RewardInfo;
    extraRewardInfo: ExtraRewardInfo;
    resignInfo: ResignInfo;
    checkInHistory: CheckInHistory;
    constructor(options?: Options);
    /**
     * @description CheckIn to claim Daily Rewards
     */
    checkIn(options?: CheckInFetchOptions): Promise<DailyRewardSignInData>;
}
export {};
