"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DailyRewards = void 0;
const constants_1 = require("../constants/constants");
const base_1 = require("./base");
const utils_1 = require("../utils");
class RewardInfo extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @description Get the daily rewards info
     */
    async fetch(options) {
        if (this.cache.has((0, utils_1.CookieObjToString)(options?.cookie) || ""))
            return this.cache.get((0, utils_1.CookieObjToString)(options?.cookie) || "");
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        });
        if (!(0, utils_1.basicValidator)("", optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { cookie, language } = optionsToUse;
        const instance = new utils_1.RequestManager({
            route: constants_1.API_URL.Genshin_HoYolab_Reward,
        });
        const res = await instance.get("info", {
            Cookie: cookie,
        }, {
            lang: language,
            act_id: "e202102251931481",
        });
        const { data } = res;
        this.cache.set(cookie, data);
        return data;
    }
    /**
     * @description Get the daily rewards details for a specific day
     * @param {number} day The day to fetch
     */
    async fetchDay(day, options) {
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        });
        if (!(0, utils_1.basicValidator)(day, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const data = await this.fetchMonth(options);
        const dayData = data.awards[day - 1];
        if (!dayData) {
            throw new Error("Day not found");
        }
        return dayData;
    }
    /**
     * @description Get the daily rewards details
     */
    async fetchMonth(options) {
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        });
        if (!(0, utils_1.basicValidator)("", optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { cookie, language } = optionsToUse;
        const instance = new utils_1.RequestManager({
            route: constants_1.API_URL.Genshin_HoYolab_Reward,
        });
        const res = await instance.get("home", {
            Cookie: cookie,
        }, {
            lang: language,
            act_id: "e202102251931481",
        });
        const { data } = res;
        (0, utils_1.alias)(data.awards, { cnt: "count" });
        return data;
    }
}
class ExtraRewardInfo extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @description Get the extra rewards info
     */
    async fetch(options) {
        if (this.cache.has((0, utils_1.CookieObjToString)(options?.cookie) || ""))
            return this.cache.get((0, utils_1.CookieObjToString)(options?.cookie) || "");
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        });
        if (!(0, utils_1.basicValidator)("", optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { cookie } = optionsToUse;
        const instance = new utils_1.RequestManager({
            route: constants_1.API_URL.Genshin_HoYolab_Reward,
        });
        const res = await instance.get("extra_award", {
            Cookie: cookie,
        }, {
            act_id: "e202102251931481",
            region: "",
            uid: "",
        });
        const { data } = res;
        (0, utils_1.alias)(data, { total_cnt: "total_count", mc: "month_card" });
        this.cache.set(cookie, data);
        return data;
    }
}
class ResignInfo extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @description get resign info
     */
    async fetch(options) {
        if (this.cache.has((0, utils_1.CookieObjToString)(options?.cookie) || ""))
            return this.cache.get((0, utils_1.CookieObjToString)(options?.cookie) || "");
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        });
        if (!(0, utils_1.basicValidator)("", optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { cookie, language } = optionsToUse;
        const instance = new utils_1.RequestManager({
            route: constants_1.API_URL.Genshin_HoYolab_Reward,
        });
        const res = await instance.get("resign_info", {
            Cookie: cookie,
        }, {
            lang: language,
            act_id: "e202102251931481",
        });
        const { data } = res;
        (0, utils_1.alias)(data, {
            resign_cnt_daily: "resign_count_daily",
            resign_cnt_monthly: "resign_count_monthly",
            sign_cnt_missed: "sign_count_missed",
            quality_cnt: "quality_count",
            sign_cnt: "sign_count",
            month_quality_cnt: "month_quality_count",
        });
        this.cache.set(cookie, data);
        return data;
    }
}
class CheckInHistory extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @description get check in history
     */
    async fetch(options) {
        if (this.cache.has((0, utils_1.CookieObjToString)(options?.cookie) || ""))
            return this.cache.get((0, utils_1.CookieObjToString)(options?.cookie) || "");
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        }, utils_1.OptionType.FetchClaimHistoryOption);
        if (!(0, utils_1.claimHistoryValidator)(optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { cookie, language, page } = optionsToUse;
        const instance = new utils_1.RequestManager({
            route: constants_1.API_URL.Genshin_HoYolab_Reward,
        });
        const res = await instance.get("award", {
            Cookie: cookie,
        }, {
            lang: language,
            act_id: "e202102251931481",
            current_page: page ?? 1,
            page_size: 10,
        });
        const { data } = res;
        (0, utils_1.alias)(data, { cnt: "count" });
        this.cache.set(cookie, data);
        return data;
    }
}
class DailyRewards {
    constructor(options) {
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "cookieManager", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "rewardInfo", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "extraRewardInfo", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "resignInfo", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "checkInHistory", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
        this.cookieManager = options?.cookieManager;
        this.rewardInfo = new RewardInfo(options);
        this.extraRewardInfo = new ExtraRewardInfo(options);
        this.resignInfo = new ResignInfo(options);
        this.checkInHistory = new CheckInHistory(options);
    }
    /**
     * @description CheckIn to claim Daily Rewards
     */
    async checkIn(options) {
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        });
        if (!(0, utils_1.basicValidator)("", optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { cookie, language } = optionsToUse;
        const instance = new utils_1.RequestManager({
            route: constants_1.API_URL.Genshin_HoYolab_Reward,
            withUA: true,
        });
        const res = await instance.post("sign", {
            Cookie: cookie,
        }, {
            act_id: "e202102251931481",
        }, {
            lang: language,
        });
        let { data } = res;
        if (res.retcode === 0 && data.gt_result.is_risk && options?.geetestCallback) {
            const geetest = await options.geetestCallback(data.gt_result.challenge, data.gt_result.gt);
            const res2 = await instance.post("sign", {
                Cookie: cookie,
            }, {
                act_id: "e202102251931481",
                "x-rpc-challenge": data.gt_result.challenge,
                "x-rpc-seccode": geetest.seccode,
                "x-rpc-validate": geetest.validate,
            }, {
                lang: language,
            });
            data = res2.data;
            if (res2.retcode === 0 && data.gt_result.is_risk) {
                return {
                    status: "geetest triggered",
                    code: res2.retcode,
                };
            }
        }
        if (res.retcode === 0 && data.gt_result.is_risk && !options?.geetestCallback) {
            return {
                status: "geetest triggered",
                code: res.retcode,
            };
        }
        if (res.retcode === -5003) {
            return {
                status: "Already claimed",
                code: -5003,
            };
        }
        if (data.code === "ok" && res.retcode === 0) {
            const info = await this.rewardInfo.fetch(options);
            const today = info.today.split("-")[2];
            const reward = await this.rewardInfo.fetchDay(parseInt(today || "1"), {
                cookie,
                language,
            });
            return {
                status: "success",
                code: res.retcode,
                rewards: reward,
            };
        }
        return {
            status: "error",
            code: res.retcode,
        };
    }
}
exports.DailyRewards = DailyRewards;
