"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CookieObjToString = exports.CookieToObj = exports.CookieFormatter = void 0;
/**
 * @param {string} ltoken - The ltoken to set.
 * @param {string} ltuid - The ltuid to set.
 * @returns {string} - The cookie for headers.
 */
function CookieFormatter(ltoken, ltuid) {
    const version = ltoken.startsWith("v2_") ? 2 : 1;
    switch (version) {
        case 1:
            return `ltoken=${ltoken}; ltuid=${ltuid};`;
        case 2:
            return `ltoken_v2=${ltoken}; ltuid_v2=${ltuid};`;
        default:
            return `ltoken=${ltoken}; ltuid=${ltuid};`;
    }
}
exports.CookieFormatter = CookieFormatter;
/**
 * @param {string} cookies - The cookie to parse.
 */
function CookieToObj(cookies) {
    const cookieObj = {};
    const cookieArr = cookies.split(";");
    cookieArr.forEach(cookie => {
        const index = cookie.indexOf("=");
        if (index !== -1) {
            const key = cookie.substring(0, index).trim();
            const value = cookie.substring(index + 1).trim();
            cookieObj[key] = value;
        }
    });
    return cookieObj;
}
exports.CookieToObj = CookieToObj;
/**
 * @param {Record<string, string> | string} cookies - The cookie to convert.
 * @returns {string | undefined} - The converted cookie.
 */
function CookieObjToString(cookies) {
    if (!cookies)
        return undefined;
    if (typeof cookies === "string") {
        return cookies;
    }
    if (Object.keys(cookies).length === 0)
        return undefined;
    return (Object.entries(cookies)
        .map(([key, value]) => `${key}=${value}`)
        .join("; ") + ";");
}
exports.CookieObjToString = CookieObjToString;
