"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.claimHistoryValidator = exports.getMonthValidator = exports.redeemValidator = exports.cardListValidator = exports.spiralAbyssValidator = exports.basicValidator = void 0;
const zod_1 = require("zod");
const basicValidator = (key, options) => {
    if (typeof key === "string") {
        const schema = zod_1.z.object({
            key: zod_1.z.string(),
            options: zod_1.z.object({
                language: zod_1.z.string(),
                cookie: zod_1.z.string().min(1),
            }),
        });
        schema.parse({ key, options });
        return true;
    }
    if (typeof key === "number") {
        const schema = zod_1.z.object({
            key: zod_1.z.number(),
            options: zod_1.z.object({
                language: zod_1.z.string(),
                cookie: zod_1.z.string().min(1),
            }),
        });
        schema.parse({ key, options });
        return true;
    }
    return false;
};
exports.basicValidator = basicValidator;
const spiralAbyssValidator = (uid, options) => {
    const schema = zod_1.z.object({
        uid: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            previous: zod_1.z.boolean().optional(),
        }),
    });
    schema.parse({ uid, options });
    return true;
};
exports.spiralAbyssValidator = spiralAbyssValidator;
const cardListValidator = (uid, options) => {
    const schema = zod_1.z.object({
        uid: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            need_avatar: zod_1.z.boolean().optional(),
            need_action: zod_1.z.boolean().optional(),
            need_stats: zod_1.z.boolean().optional(),
            offset: zod_1.z.number().optional(),
            limit: zod_1.z.number().optional(),
        }),
    });
    schema.parse({ uid, options });
    return true;
};
exports.cardListValidator = cardListValidator;
const redeemValidator = (code, options) => {
    const schema = zod_1.z.object({
        code: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            account_id: zod_1.z.string().min(1),
            cookie_token: zod_1.z.string().min(1),
            uid: zod_1.z.string(),
        }),
    });
    schema.parse({ code, options });
    return true;
};
exports.redeemValidator = redeemValidator;
const getMonthValidator = (uid, options) => {
    const schema = zod_1.z.object({
        uid: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            month: zod_1.z.number(),
        }),
    });
    schema.parse({ uid, options });
    return true;
};
exports.getMonthValidator = getMonthValidator;
const claimHistoryValidator = (options) => {
    const schema = zod_1.z.object({
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            page: zod_1.z.number().optional(),
        }),
    });
    schema.parse({ options });
    return true;
};
exports.claimHistoryValidator = claimHistoryValidator;
